@@ -44,6 +44,7 @@ use Log::Any::Adapter;
 use Params::Validate qw( :all );
 use Try::Tiny;
 use Web::Machine;
+use Web::MREST::Util qw( normalize_filespec );
 
 
 
@@ -57,11 +58,11 @@ App::Dochazka::REST - Dochazka REST server
 
 =head1 VERSION
 
-Version 0.401
+Version 0.407
 
 =cut
 
-our $VERSION = '0.401';
+our $VERSION = '0.407';
 
 
 =head2 Development status
@@ -1026,7 +1027,7 @@ and, second, a file therein:
     # cat << EOF > /etc/dochazka-rest/REST_SiteConfig.pm
     set( 'DOCHAZKA_REST_DEBUG_MODE', 1 );
     set( 'DBINIT_CONNECT_SUPERAUTH', 'mypass' );
-    set( 'DOCHAZKA_REST_LOG_FILE', $ENV{'HOME'} . "/dochazka-rest.log" );
+    set( 'DOCHAZKA_REST_LOG_FILE', "dochazka-rest.log" );
     set( 'DOCHAZKA_REST_LOG_FILE_RESET', 1);
     EOF
     #
@@ -1252,8 +1253,9 @@ sub init_no_db {
     } else {
         $debug_mode = $site->DOCHAZKA_REST_DEBUG_MODE || 0;
     }
-    unlink $site->DOCHAZKA_REST_LOG_FILE if $site->DOCHAZKA_REST_LOG_FILE_RESET;
-    Log::Any::Adapter->set('File', $site->DOCHAZKA_REST_LOG_FILE );
+    my $logfile = normalize_filespec( $site->DOCHAZKA_REST_LOG_FILE );
+    unlink $logfile if $site->DOCHAZKA_REST_LOG_FILE_RESET;
+    Log::Any::Adapter->set('File', $logfile );
     $log->init( ident => $site->DOCHAZKA_APPNAME, debug_mode => $debug_mode );
     $log->info( "Initializing " . $site->DOCHAZKA_APPNAME );
 
