@@ -55,11 +55,11 @@ App::Dochazka::REST::Dispatch::ACL - ACL module
 
 =head1 VERSION
 
-Version 0.401
+Version 0.407
 
 =cut
 
-our $VERSION = '0.401';
+our $VERSION = '0.407';
 
 
 
@@ -79,7 +79,7 @@ This module provides helper code for ACL checks.
 =cut
 
 use Exporter qw( import );
-our @EXPORT_OK = qw( check_acl check_acl_context acl_check_iid_lid );
+our @EXPORT_OK = qw( check_acl check_acl_context acl_check_is_me acl_check_iid_lid );
 
 
 
@@ -167,6 +167,36 @@ sub check_acl_context {
 }
 
 
+=head2 acl_check_is_me
+
+Takes a property and a value. The property can be either 'eid' or 'nick'.
+This routine checks the eid/nick against C<< $self->context->{'current_obj'} >>
+(the current employee object) and returns a boolean value answering the
+question "is this me?"
+
+=cut
+
+sub acl_check_is_me {
+    my $self = shift;
+    my %pl = @_;
+    $log->debug( "Entering " . __PACKAGE__ . "::acl_check_is_me with " . Dumper( \%pl ) );
+
+    my $ce = $self->context->{'current_obj'};
+    my $priv = $self->context->{'current_priv'};
+
+    return 1 if $priv eq 'admin';
+
+    if ( my $eid = $pl{'eid'} ) {
+        $log->debug( "acl_check_is_me: I am EID " . $ce->eid . " - checking against $eid" );
+        return ( $eid == $ce->eid );
+    } elsif ( my $nick = $pl{'nick'} ) {
+        return ( $nick eq $ce->nick );
+    }
+
+    die "AAAAGAGAGAHHHHAHAHAAJJAJAJAJAAHAHAHA! " . Dumper( \%pl );
+}
+
+
 =head2 acl_check_iid_lid
 
 When a user attempts to access an interval by IID, or a lock by LID, this
