@@ -68,11 +68,11 @@ App::Dochazka::REST::Auth - HTTP request authentication and authorization
 
 =head1 VERSION
 
-Version 0.401
+Version 0.407
 
 =cut
 
-our $VERSION = '0.401';
+our $VERSION = '0.407';
 
 
 
@@ -417,7 +417,8 @@ sub forbidden {
         $self->push_onto_context( { 'acl_priv' => $acl_priv } );
         return 0;
     }
-    $self->mrest_declare_status( explanation => "ACL check failed for resource $resource_name" );
+    $self->mrest_declare_status( explanation => 'DISPATCH_ACL_CHECK_FAILED', 
+        args => [ $resource_name ] );
     return 1;
 }
 
