@@ -40,7 +40,7 @@ use strict;
 use warnings;
 
 use App::CELL qw( $CELL $log $core $meta $site );
-use App::Dochazka::REST::ACL qw( check_acl_context acl_check_iid_lid );
+use App::Dochazka::REST::ACL qw( check_acl_context acl_check_is_me acl_check_iid_lid );
 use App::Dochazka::REST::ConnBank qw( conn_status );
 use App::Dochazka::REST::Model::Activity;
 use App::Dochazka::REST::Model::Employee qw( noof_employees_by_priv );
@@ -77,11 +77,11 @@ App::Dochazka::REST::Dispatch - Implementation of top-level resources
 
 =head1 VERSION
 
-Version 0.401
+Version 0.407
 
 =cut
 
-our $VERSION = '0.401';
+our $VERSION = '0.407';
 
 
 =head1 DESCRIPTION
@@ -1003,9 +1003,20 @@ sub handler_get_employee_eid {
 
     # first pass
     if ( $pass == 1 ) {
-        my $emp = shared_first_pass_lookup( $self, 'EID', $self->context->{'mapping'}->{'eid'} );
+        #,
+        # 403 (ACL) check - passerby can only look up him- or herself
+        #
+        my $eid = $self->context->{'mapping'}->{'eid'};
+        if ( ! acl_check_is_me( $self, 'eid' => $eid ) ) {
+            $self->mrest_declare_status( code => 403, explanation => "DISPATCH_KEEP_TO_YOURSELF" );
+            return 0;
+        }
+        # 
+        # 404 check
+        #
+        my $emp = shared_first_pass_lookup( $self, 'EID', $eid );
         return 0 unless $emp;
-        return 0 unless shared_employee_acl_part1( $self, $emp );  # additional ACL checks
+        #return 0 unless shared_employee_acl_part1( $self, $emp );  # additional ACL checks
         $self->context->{'stashed_employee_object'} = $emp;
         return 1;
     }
@@ -1049,6 +1060,16 @@ sub handler_get_employee_nick {
 
     # first pass
     if ( $pass == 1 ) {
+        #
+        # ACL check - passerby can only look up him- or herself
+        my $priv = $self->context->{'current_priv'};
+        my $nick = $self->context->{'mapping'}->{'nick'};
+        if ( $priv ne 'admin' ) {
+            if ( ! acl_check_is_me( $self, 'nick' => $nick ) ) {
+                $self->mrest_declare_status( code => 403, explanation => "DISPATCH_KEEP_TO_YOURSELF" );
+                return 0;
+            }
+        }
         my $emp = shared_first_pass_lookup( $self, 'nick', $self->context->{'mapping'}->{'nick'} );
         return 0 unless $emp;
         $self->context->{'stashed_employee_object'} = $emp;
@@ -1221,7 +1242,7 @@ sub handler_history_post {
         $log->crit($_);
         return $CELL->status_crit("DISPATCH_HISTORY_COULD_NOT_SPAWN", args => [ $_ ] );
     };
-    my $status = $ho->insert( $context );
+    $status = $ho->insert( $context );
     if ( $status->not_ok ) {
         $self->context->{'create_path'} = $status->level;
         if ( $status->code eq 'DOCHAZKA_MALFORMED_400' ) {
@@ -1846,7 +1867,8 @@ sub handler_lock_lid {
 sub handler_priv_get_eid {
     my ( $self, $pass ) = @_;
     $log->debug( "Entering " . __PACKAGE__ . ":handler_priv_get_eid" ); 
-    return shared_get_privsched( $self, 'priv', $pass, 'EID', $self->context->{'mapping'}->{'eid'} );
+    my $eid = $self->context->{'mapping'}->{'eid'};
+    return shared_get_privsched( $self, 'priv', $pass, 'EID', $eid );
 }
 
 
@@ -1857,7 +1879,8 @@ sub handler_priv_get_eid {
 sub handler_priv_get_nick {
     my ( $self, $pass ) = @_;
     $log->debug( "Entering " . __PACKAGE__ . ":handler_priv_get_nick" ); 
-    return shared_get_privsched( $self, 'priv', $pass, 'nick', $self->context->{'mapping'}->{'nick'} );
+    my $nick = $self->context->{'mapping'}->{'nick'};
+    return shared_get_privsched( $self, 'priv', $pass, 'nick', $nick );
 }
 
 
