@@ -54,11 +54,11 @@ App::Dochazka::REST::ResourceDefs - Resource definitions
 
 =head1 VERSION
 
-Version 0.401
+Version 0.407
 
 =cut
 
-our $VERSION = '0.401';
+our $VERSION = '0.407';
 
 
 
@@ -704,7 +704,7 @@ EOH
             DELETE => 'handler_delete_employee_eid',
         },
         acl_profile => {
-            GET => 'inactive', 
+            GET => 'passerby', 
             PUT => 'inactive',
             DELETE => 'admin',
         },
@@ -790,7 +790,7 @@ EOH
             DELETE => 'handler_delete_employee_nick',
         },
         acl_profile => {
-            GET => 'inactive',
+            GET => 'passerby',
             PUT => 'inactive',
             DELETE => 'admin', 
         },
@@ -877,6 +877,28 @@ implicitly be added. Example: a search for 'foo' would be converted to
 EOH
     },
 
+    # /employee/sec_id/:sec_id
+    'employee/sec_id/:sec_id' =>
+    {
+        parent => 'employee',
+        handler => {
+            GET => 'handler_get_employee_sec_id',
+        },
+        acl_profile => {
+            GET => 'passerby'
+        },
+        cli => 'employee sec_id $SEC_ID',
+        description => 'GET an employee profile by the employee\'s secondary ID',
+        validations => {
+            'sec_id' => qr/^[%[:alnum:]_][%[:alnum:]_-]+$/,
+        },
+        documentation => <<'EOH',
+=pod
+
+Retrieves an employee object by the secondary ID (must be an exact match)
+EOH
+    },
+
     # /employee/self
     'employee/self' =>
     { 
@@ -1811,7 +1833,7 @@ EOH
         handler => {
             GET => 'handler_priv_get_eid',
         },
-        acl_profile => 'admin', 
+        acl_profile => 'passerby', 
         cli => 'priv eid $EID [$TIMESTAMP]',
         validations => {
             'eid' => 'Int',
