@@ -40,6 +40,7 @@ use strict;
 use warnings;
 
 use App::CELL qw( $CELL $log $site );
+use App::Dochazka::REST::ACL qw( acl_check_is_me );
 use App::Dochazka::REST::ConnBank qw( conn_status );
 use App::Dochazka::REST::Model::Activity;
 use App::Dochazka::REST::Model::Employee;
@@ -66,11 +67,11 @@ App::Dochazka::REST::Dispatch::Shared - Shared dispatch functions
 
 =head1 VERSION
 
-Version 0.401
+Version 0.407
 
 =cut
 
-our $VERSION = '0.401';
+our $VERSION = '0.407';
 
 my $fail = $CELL->status_not_ok;
 
@@ -429,7 +430,17 @@ sub shared_get_privsched {
 
     # first pass
     if ( $pass == 1 ) {
-        my $emp = shared_first_pass_lookup( $self, $key, $value );
+        #
+        # 403 (ACL) check - passerby can only look up him- or herself
+        #
+        if ( ! acl_check_is_me( $self, ( lc $key ) => $value ) ) {
+            $self->mrest_declare_status( code => 403, explanation => "DISPATCH_KEEP_TO_YOURSELF" );
+            return 0;
+        }
+        # 
+        # 404 check
+        #
+        my $emp = shared_first_pass_lookup( $self, $key => $value );
         return 0 unless $emp;
         $self->context->{'stashed_employee_object'} = $emp;
         return 1;
@@ -510,14 +521,12 @@ sub shared_employee_acl_part1 {
     # update
     if ( $cp eq 'admin' ) {
         return 1;
-    } elsif ( $cp =~ m/^(inactive)|(active)$/i ) {
+    } else {
         if ( $this_emp->eid == $context->{'current'}->{'eid'} ) {
             return 1;
         }
     }
-    $self->mrest_declare_status( code => 403,
-        explanation => "Employees with privlevel $cp may update their own profile only"
-    );
+    $self->mrest_declare_status( code => 403, explanation => "DISPATCH_KEEP_TO_YOURSELF" );
     return 0;
 }
 
